@@ -124,8 +124,9 @@ std::string configlist [] = {
 
     "STate [s]",           "* autoload default at start (ON, {other})",
     "SIngle [s]",          "* force 2nd startup to open new instance instead (ON, {other})",
-    "Hide [s]",            "non-fatal errors (ON, {other})",
-    "Display [s]",         "GUI splash screen (ON, {other})",
+    "Hide [s]",            "non-essential reports (ON, {other})",
+    "Warn [s]",            "warn parts have changed if loading or resetting (ON, {other})",
+    //"Display [s]",         "GUI splash screen (ON, {other})",
     "Time [s]",            "add to instrument load message (ON, {other})",
     "Include [s]",         "XML headers on file load(Enable {other})",
     "Keep [s]",            "include inactive data on all file saves (ON, {other})",
@@ -150,6 +151,7 @@ std::string configlist [] = {
     "PRogram [s]",         "program change (ON, {other})",
     "EXTended [n]",        "CC value for extended program change >= 120 is off",
     "Quiet [s]",           "ignore 'reset all controllers' (ON, {other})",
+    "OMni [s]",            "enable omni mode change (ON, {other})",
     "Nrpn [s]",            "incoming NRPN (ON, {other})",
     "Log [s]",             "incoming MIDI CCs (ON, {other})",
     "SHow [s]",            "GUI MIDI learn editor (ON, {other})",
@@ -217,6 +219,7 @@ std::string partlist [] = {
     "CLear [s]",           "sets current instrument level parameters to default.",
     "",                    "ALL, resets the entire part, including controllers etc.",
     "CHannel <n>",         "MIDI channel (> 32 disables, > 16 note off only)",
+    "OMni <s>",            "Omni mode (ON, {other})",
     "AFtertouch Chan <s1> [s2]", "Off, Filter (Down) + Peak (Down) + Bend (Down) + Modulation + Volume",
     "AFtertouch Key <s1> [s2]",  "Off, Filter (Down) + Peak (Down) + Bend (Down) + Modulation",
     "Destination <s>",     "jack audio destination (Main, Part, Both)",
