@@ -32,7 +32,7 @@
 #include "Misc/NumericFuncs.h"
 
 class SynthEngine;
-class XMLwrapper;
+class XMLtree;
 
 using std::string;
 using func::power;
@@ -90,8 +90,8 @@ class Microtonal
         string Pname;
         string Pcomment;
 
-        void add2XML(XMLwrapper&);
-        int  getfromXML(XMLwrapper&);
+        void add2XML(XMLtree&);
+        int  getfromXML(XMLtree&);
         bool saveXML(string const& filename);
         int  loadXML(string const& filename);
 
